@@ -8,6 +8,7 @@ from pedal.cait.find_node import find_operation, find_function_calls, find_funct
 from pedal.core.feedback import CompositeFeedbackFunction
 from pedal.core.location import Location
 from pedal.core.report import MAIN_REPORT
+from pedal.core.commands import compliment as core_compliment, give_partial
 from pedal.types.normalize import normalize_type
 from pedal.types.operations import are_types_equal
 from pedal.utilities.ast_tools import AST_NODE_NAMES
@@ -89,6 +90,9 @@ class ensure_function_call(EnsureAssertionFeedback):
     Determine that a function was definitely called by statically checking
     the students' code.
 
+    # TODO: Allow parameter to force this to be a method xor/or function call
+    # TODO: Allow set to be passed in for OR, or list for AND, for multiples
+
     # TODO: also check the TIFA records to see if the function was read
 
     Args:
@@ -404,7 +408,7 @@ class ensure_documented_functions(AssertionFeedback):
     """ Checks that all of the functions in the source code are documented. """
     title = "Must Document Functions"
     message_template = ("You must document the following function{plural}:"
-                        ": {names_message}.")
+                        " {names_message}.")
 
     def __init__(self, root=None, **kwargs):
         report = kwargs.get('report', MAIN_REPORT)
@@ -456,7 +460,7 @@ function_prints => ensure_function_call('print', root=match_signature('name')
 
 @CompositeFeedbackFunction(missing_function, duplicate_function_definition)
 def ensure_function(name, arity=None, parameters=None,
-                    returns=None, root=None, **kwargs):
+                    returns=None, root=None, compliment=False, **kwargs):
     """ Checks that the function exists and has the right signature. """
     report = kwargs.get('report', MAIN_REPORT)
     root = root or parse_program(report=report)
@@ -513,6 +517,14 @@ def ensure_function(name, arity=None, parameters=None,
             return wrong_return_type(name, actual_returns, expected_returns,
                                      **kwargs)
     # Alternatively, returns positive FF?
+    if compliment:
+        if isinstance(compliment, str):
+            core_compliment(compliment, label="function_defined", **kwargs)
+        elif compliment is True:
+            core_compliment(f"Defined {name}", label="function_defined", **kwargs)
+    elif kwargs.get("score"):
+        give_partial(kwargs.pop("score"), label="function_defined", **kwargs)
+
     return None
 
 
