@@ -83,6 +83,9 @@ def parse_args(reduced_mode=False):
                                             'instructor control script.',
                         default='submissions',
                         nargs='?')
+    parser.add_argument("--alternate_filenames",
+                        help="A semicolon separated list of potential filenames to try if the main isn't found.",
+                        default="")
     # TODO: Handle output to file
     parser.add_argument('--output', '-o',
                         help='The output file path for the result. Defaults to stdout.',
@@ -129,6 +132,10 @@ def parse_args(reduced_mode=False):
     parser.add_argument('--cache', help='Use the given directory to hold the cache.'
                                         ' You can use "./" to use the current directory.',
                         default=False)
+    # TODO: Want to allow for multiple threads too to parallel process data (faster!)
+    parser.add_argument('--threaded', help='Run the instructor script in a separate thread to avoid'
+                                           ' timeout crashes.',
+                        default=False)
     '''
     parser.add_argument('--include_submissions', help='An optional REGEX filter '
                                                       'to only include certain submissions')
